note
	description: "Summary description for {FOREST_RENDERER}."
	author: "iroesch"
	date: "$Date$"
	revision: "$Revision$"

class
	FOREST_RENDERER

create
	make_with_window

feature -- creation

	make_with_window (a_window: MAIN_WINDOW)
			-- creates the renderer and binds it to the window `a_window'
		require
			a_window_exists: a_window /= Void
		do
			Parent_window := a_window

				-- create the drawing-area.
			create Window_pixmap
			Window_pixmap.set_size (Parent_window.width, Parent_window.height)

				-- create the forest logic with the forest
			create forest_fire.make

				-- create the container where our drawing pixmap lives in.
			create Container
			Parent_window.extend (Container)
			Container.extend (Window_pixmap)

				-- load the graphics and render once.
			load_graphics
			render
		end

feature -- rendering

	render
			-- Render the forest.
		local
			row, col: INTEGER
			tile: EV_PIXMAP
		do
			Window_pixmap.clear
			from
				row := 1
			until
				forest_fire.map.height < row
			loop
				from
					col := 1
				until
					forest_fire.map.width < col
				loop
					Window_pixmap.draw_pixmap ((col - 1) * Tile_size, (row - 1) * Tile_size, grass_tile)
					if forest_fire.map [row, col] = {FOREST_FIRE}.Tree then
						Window_pixmap.draw_pixmap ((col - 1) * Tile_size, (row - 1) * Tile_size, tree_tile)
					elseif forest_fire.map [row, col] = {FOREST_FIRE}.Fire then
						Window_pixmap.draw_pixmap ((col - 1) * Tile_size, (row - 1) * Tile_size, fire_tile)
					end
					col := col + 1
				end
				row := row + 1
			end
			if not Parent_window.is_destroyed then
				Parent_window.refresh_now
			end
		end

	load_graphics
			-- load pixmaps.
		do
			create grass_tile.make_with_size (Tile_size, Tile_size)
			grass_tile.set_with_named_file ("Images/grass.png")
			create tree_tile.make_with_size (Tile_size, Tile_size)
			tree_tile.set_with_named_file ("Images/tree.png")
			create fire_tile.make_with_size (Tile_size, Tile_size)
			fire_tile.set_with_named_file ("Images/fire.png")
		end

	render_step
		do
			forest_fire.do_step
			render
		end

feature -- Constants

	Tile_size: INTEGER = 20
			-- the length of a tile in pixel

feature {NONE} -- Tiles and other pixmaps

	grass_tile: EV_PIXMAP
			-- graphical representation of an empty field

	tree_tile: EV_PIXMAP
			-- graphical representation of a tree

	fire_tile: EV_PIXMAP
			-- graphial representation of a fire

	Window_pixmap: EV_PIXMAP
			-- the drawing area

	Parent_window: EV_TITLED_WINDOW
			-- the window we are rendering in

	Container: EV_FIXED
			-- the container our drawing area is in

feature

	forest_fire: FOREST_FIRE
			-- the logic that simulates the forest fire

end
